"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateDto = void 0;
function validateDto(dto, dtoType) {
    const constrainedKeys = Reflect.getMetadata("dto:validation", dtoType.prototype);
    if (!constrainedKeys)
        return true;
    const isNotValid = Object.getOwnPropertyNames(constrainedKeys).some((constrainedKeyName) => {
        const keyConstraints = constrainedKeys[constrainedKeyName];
        const value = dto[keyConstraints.name];
        if (!value && keyConstraints.required)
            return true;
        else if (value) {
            const dtoTypeMod = typeof value === "object" ? (Array.isArray(value) ? "array" : typeof value) : typeof value;
            if (keyConstraints.checkType && dtoTypeMod !== keyConstraints.type.toLowerCase()) {
                return true;
            }
            if (keyConstraints.maxLength && value.length > keyConstraints.maxLength) {
                return true;
            }
            if (keyConstraints.minLength && value.length < keyConstraints.minLength) {
                return true;
            }
            if (keyConstraints.type === "number" && typeof value === "number" && keyConstraints.range) {
                if (value < keyConstraints.range[0] || value > keyConstraints.range[1])
                    return true;
            }
        }
        return false;
    });
    if (isNotValid)
        return false;
    else
        return true;
}
exports.validateDto = validateDto;
//# sourceMappingURL=validateDto.js.map